@@ -1,9 +1,10 @@
+skip_on_cran()
+skip_on_ci()
+
 test_that("all_surveys() sends the proper request to Qualtrics", {
+  local_mocked_bindings(glue_api_v3 = function(base_url) "https://stoplight.io/mocks/qualtricsv2/publicapidocs/60937")
 
-  vcr::use_cassette("all_surveys", {
-    x <- all_surveys()
-  })
-
+  x <- all_surveys()
   expect_s3_class(x, c("tbl_df","tbl","data.frame"))
   expect_named(x, c("id", "name", "ownerId", "lastModified",
                     "creationDate", "isActive"))
@@ -13,24 +14,11 @@ test_that("all_surveys() sends the proper request to Qualtrics", {
   expect_type(x$lastModified, "character")
   expect_type(x$creationDate, "character")
   expect_type(x$isActive, "logical")
-
 })
 
-
-# Set to bad URL:
-qualtrics_api_credentials(api_key = "1234",
-                          base_url = "t.qualtrics.com")
-
 test_that("all_surveys() throws an error when URL & key is bad", {
-
-  skip_on_cran()
-
-  expect_error(
-    all_surveys(),
-    "You may not have the required authorization"
+  withr::with_envvar(
+    new = c("QUALTRICS_API_KEY" = "abcdef", "QUALTRICS_BASE_URL" = "t.qualtrics.com"), 
+    expect_snapshot_error(all_surveys())
   )
 })
-
-# Reset the credentials:
-qualtrics_api_credentials(api_key = holder_API, base_url = holder_URL)
-
