@@ -1,11 +1,10 @@
+skip_on_cran()
+skip_on_ci()
+
 test_that("fetch_distribution_history() returns a tbl_df with expected column names and types", {
-
-  skip_on_cran()
-
-  vcr::use_cassette("fetch_distribution_history", {
-    x <- fetch_distribution_history("EMD_RmjB8Gfpjlki6ms")
-  })
-
+  local_mocked_bindings(glue_api_v3 = function(base_url) "https://stoplight.io/mocks/qualtricsv2/publicapidocs/60919")
+  
+  x <- fetch_distribution_history("EMD_abcdef123456789")
   expect_s3_class(x, c("tbl_df", "tbl", "data.frame"))
   expect_s3_class(x$responseCompletedAt,  c("POSIXct", "POSIXt"))
   expect_s3_class(x$sentAt,  c("POSIXct", "POSIXt"))
